Show Foods

National Nutrient Database for Standard Reference
Release 25
Basic Report

# Nutrient data for 07908, Luncheon meat, pork with ham, minced, canned, includes SPAM (Hormel)

Return to Search Results
Full Report (All Nutrients)
Statistics Report
Modifying household measures

Nutrient values and weights are for edible portion

| Nutrient | Unit | Value per 100.0g | oz 1 NLEA serving 56g
Proximates
Water | g | 51.70 | 28.95
Energy | kcal | 315 | 176
Protein | g | 13.40 | 7.50
Total lipid (fat) | g | 26.60 | 14.90
Carbohydrate, by difference | g | 4.60 | 2.58
Fiber, total dietary | g | 0.0 | 0.0
Sugars, total | g | 0.00 | 0.00
Minerals
Calcium, Ca | mg | 0 | 0
Iron, Fe | mg | 0.64 | 0.36
Magnesium, Mg | mg | 14 | 8
Phosphorus, P | mg | 151 | 85
Potassium, K | mg | 409 | 229
Sodium, Na | mg | 1411 | 790
Zinc, Zn | mg | 1.59 | 0.89
Vitamins
Vitamin C, total ascorbic acid | mg | 0.0 | 0.0
Thiamin | mg | 0.317 | 0.178
Riboflavin | mg | 0.176 | 0.099
Niacin | mg | 3.530 | 1.977
Vitamin B-6 | mg | 0.218 | 0.122
Folate, DFE | µg | 3 | 2
Vitamin B-12 | µg | 0.45 | 0.25
Vitamin A, RAE | µg | 0 | 0
Vitamin A, IU | IU | 0 | 0
Vitamin E (alpha-tocopherol) | mg | 0.42 | 0.24
Vitamin D (D2 + D3) | µg | 0.6 | 0.3
Vitamin D | IU | 26 | 15
Vitamin K (phylloquinone) | µg | 0.0 | 0.0
Lipids
Fatty acids, total saturated | g | 9.987 | 5.593
Fatty acids, total monounsaturated | g | 13.505 | 7.563
Fatty acids, total polyunsaturated | g | 2.019 | 1.131
Cholesterol | mg | 71 | 40
Other
Caffeine | mg | 0 | 0